Yidi Lin has submitted this change. ( https://review.coreboot.org/c/coreboot/+/85751?usp=email )
Change subject: soc/mediatek/mt8196: Set SPMI-P SCL/SDA pins to pull-down
......................................................................
soc/mediatek/mt8196: Set SPMI-P SCL/SDA pins to pull-down
The current Pull-Down capabilities of the SPMI are insufficient and
require optimization. Configure the SCL and SDA of the SPMI-P to
Pull-Down mode on MT8196 SoC side. It is done only once during the SPMI
read check to fix SPMI clock calibration failure.
TEST=Build pass
BUG=b:361174333
Change-Id: Idbf8ed8e31850ca81c823db1b25bde4a83a48c4f
Signed-off-by: Hope Wang <hope.wang(a)mediatek.corp-partner.google.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/85751
Reviewed-by: Yu-Ping Wu <yupingso(a)google.com>
Reviewed-by: Yidi Lin <yidilin(a)google.com>
Tested-by: build bot (Jenkins) <no-reply(a)coreboot.org>
---
M src/soc/mediatek/mt8196/pmif_spmi.c
1 file changed, 3 insertions(+), 0 deletions(-)
Approvals:
build bot (Jenkins): Verified
Yu-Ping Wu: Looks good to me, approved
Yidi Lin: Looks good to me, approved
diff --git a/src/soc/mediatek/mt8196/pmif_spmi.c b/src/soc/mediatek/mt8196/pmif_spmi.c
index 91f9038..d00afe1 100644
--- a/src/soc/mediatek/mt8196/pmif_spmi.c
+++ b/src/soc/mediatek/mt8196/pmif_spmi.c
@@ -167,6 +167,9 @@
/* SPMI_P 14mA */
gpio_set_driving(GPIO(SPMI_P_SCL), GPIO_DRV_14_MA);
gpio_set_driving(GPIO(SPMI_P_SDA), GPIO_DRV_14_MA);
+ /* SPMI-P set Pull-Down mode */
+ gpio_set_pull(GPIO(SPMI_P_SCL), GPIO_PULL_ENABLE, GPIO_PULL_DOWN);
+ gpio_set_pull(GPIO(SPMI_P_SDA), GPIO_PULL_ENABLE, GPIO_PULL_DOWN);
printk(BIOS_INFO, "%s done\n", __func__);
}
--
To view, visit https://review.coreboot.org/c/coreboot/+/85751?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: merged
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Idbf8ed8e31850ca81c823db1b25bde4a83a48c4f
Gerrit-Change-Number: 85751
Gerrit-PatchSet: 10
Gerrit-Owner: Jarried Lin <jarried.lin(a)mediatek.com>
Gerrit-Reviewer: Hope Wang <hope.wang(a)mediatek.corp-partner.google.com>
Gerrit-Reviewer: Hung-Te Lin <hungte(a)chromium.org>
Gerrit-Reviewer: Yidi Lin <yidilin(a)google.com>
Gerrit-Reviewer: Yu-Ping Wu <yupingso(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Attention is currently required from: Angel Pons, Keith Hui.
Riku Viitanen has posted comments on this change by Riku Viitanen. ( https://review.coreboot.org/c/coreboot/+/85772?usp=email )
Change subject: mb/asrock: Add Z77 Extreme4
......................................................................
Patch Set 12:
(2 comments)
Patchset:
PS12:
> Do you have to do anything special to make a PS/2 mouse work?
Nope, it just works automatically in Devuan Daedalus (Linux 6.1 and Xfce 4.18).
Kinda makes sense, since in vendor firmware there's also no setting to choose between a mouse and a keyboard.
But on the other hand I recall seeing some other board in coreboot that had some issues with PS/2 mice connected like this.
File src/mainboard/asrock/z77_extreme4/early_init.c:
https://review.coreboot.org/c/coreboot/+/85772/comment/44bcd991_f8be791c?us… :
PS12, Line 10: if (CONFIG(CONSOLE_SERIAL))
> The function will no-op itself if this config is not selected, so it's not necessary.
Ack. Having the "if" here makes more sense imo. But yeah it's a bit redundant at the moment. Many other boards do this too, perhaps we should consistently have one style or the other.
--
To view, visit https://review.coreboot.org/c/coreboot/+/85772?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Idf028c6d411bd501b73a3c526240d0b1d6ecaa0c
Gerrit-Change-Number: 85772
Gerrit-PatchSet: 12
Gerrit-Owner: Riku Viitanen <riku.viitanen(a)protonmail.com>
Gerrit-Reviewer: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Reviewer: Nicholas Chin <nic.c3.14(a)gmail.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-CC: Keith Hui <buurin(a)gmail.com>
Gerrit-Attention: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Attention: Keith Hui <buurin(a)gmail.com>
Gerrit-Comment-Date: Wed, 01 Jan 2025 12:38:20 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: Keith Hui <buurin(a)gmail.com>
Attention is currently required from: Christian Walter, Johnny Lin, Jonathan Zhang, Morgan Jang, Patrick Rudolph, Shuo Liu, Tim Chu.
Angel Pons has posted comments on this change by Patrick Rudolph. ( https://review.coreboot.org/c/coreboot/+/85805?usp=email )
Change subject: soc/intel/xeon_sp/skx: Enable x86_64
......................................................................
Patch Set 3: Code-Review+2
(1 comment)
File src/vendorcode/intel/fsp/fsp2_0/skylake_sp/FspmUpd.h:
https://review.coreboot.org/c/coreboot/+/85805/comment/26d14202_879bc3c6?us… :
PS3, Line 514: 48
24 + 4 + 20 = 48
--
To view, visit https://review.coreboot.org/c/coreboot/+/85805?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: I8adac99e7600a708b596fd74b00669f4cb4e041b
Gerrit-Change-Number: 85805
Gerrit-PatchSet: 3
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Reviewer: Christian Walter <christian.walter(a)9elements.com>
Gerrit-Reviewer: Johnny Lin <Johnny_Lin(a)wiwynn.com>
Gerrit-Reviewer: Jonathan Zhang <jon.zhixiong.zhang(a)gmail.com>
Gerrit-Reviewer: Morgan Jang <Morgan_Jang(a)wiwynn.com>
Gerrit-Reviewer: Shuo Liu <shuo.liu(a)intel.com>
Gerrit-Reviewer: Tim Chu <Tim.Chu(a)quantatw.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Attention: Jonathan Zhang <jon.zhixiong.zhang(a)gmail.com>
Gerrit-Attention: Johnny Lin <Johnny_Lin(a)wiwynn.com>
Gerrit-Attention: Christian Walter <christian.walter(a)9elements.com>
Gerrit-Attention: Shuo Liu <shuo.liu(a)intel.com>
Gerrit-Attention: Morgan Jang <Morgan_Jang(a)wiwynn.com>
Gerrit-Attention: Tim Chu <Tim.Chu(a)quantatw.com>
Gerrit-Comment-Date: Wed, 01 Jan 2025 11:42:52 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Attention is currently required from: Nicholas Chin.
Angel Pons has posted comments on this change by Nicholas Chin. ( https://review.coreboot.org/c/coreboot/+/85790?usp=email )
Change subject: util/find_usbdebug: Fix lsusb -t parsing for usbutils v016 and newer
......................................................................
Patch Set 3: Code-Review+2
--
To view, visit https://review.coreboot.org/c/coreboot/+/85790?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Iffa1238b995d387d6e51459f85ae96da52a5c0ff
Gerrit-Change-Number: 85790
Gerrit-PatchSet: 3
Gerrit-Owner: Nicholas Chin <nic.c3.14(a)gmail.com>
Gerrit-Reviewer: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Reviewer: Jan Philipp Groß <jeangrande(a)mailbox.org>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Nicholas Chin <nic.c3.14(a)gmail.com>
Gerrit-Comment-Date: Wed, 01 Jan 2025 11:31:19 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Subrata Banik has submitted this change. ( https://review.coreboot.org/c/coreboot/+/85781?usp=email )
Change subject: soc/intel/pantherlake: Update the Thunderbolt lcap_port_base to 21
......................................................................
soc/intel/pantherlake: Update the Thunderbolt lcap_port_base to 21
Document #815002 Panther Lake H Processor - 2.3 Device IDs - Table 8
"Other Device ID" specifies that the first Thunderbolt PCIe root port
number is 21.
The previous offset of 0x10, inherited from Meteor Lake code, caused
an issue that resulted in:
- Temporary deactivation of Thunderbolt PCI devices during ramstage
- Failure to generate critical ACPI SSDT power management data for the
port
This error led to instability in PCIe tunneling during power state
transitions.
Change-Id: I44f91f954a4ec06c56dcc90d97e7da2193e9acf2
Signed-off-by: Jeremy Compostella <jeremy.compostella(a)intel.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/85781
Reviewed-by: Subrata Banik <subratabanik(a)google.com>
Tested-by: build bot (Jenkins) <no-reply(a)coreboot.org>
---
M src/soc/intel/pantherlake/pcie_rp.c
1 file changed, 7 insertions(+), 5 deletions(-)
Approvals:
build bot (Jenkins): Verified
Subrata Banik: Looks good to me, approved
diff --git a/src/soc/intel/pantherlake/pcie_rp.c b/src/soc/intel/pantherlake/pcie_rp.c
index 1b302fd..604e7af 100644
--- a/src/soc/intel/pantherlake/pcie_rp.c
+++ b/src/soc/intel/pantherlake/pcie_rp.c
@@ -5,13 +5,15 @@
#include <soc/pcie.h>
/*
* TBT's LCAP registers are returning port index which starts from 0x10 (Usually for other PCIe
* root ports index starts from 1). Thus keeping lcap_port_base 0x10 for TBT, so that coreboot's
* PCIe remapping logic can return correct index (0-based)
*/
static const struct pcie_rp_group tbt_rp_groups[] = {
- { .slot = PCI_DEV_SLOT_TBT, .count = CONFIG_MAX_TBT_ROOT_PORTS, .lcap_port_base = 0x10 },
+ { .slot = PCI_DEV_SLOT_TBT, .count = CONFIG_MAX_TBT_ROOT_PORTS, .lcap_port_base = 21 },
{ 0 }
};
@@ -5,13 +5,15 @@
#include <soc/pcie.h>
/*
- * TBT's LCAP registers are returning port index which starts from 0x10 (Usually for other PCIe
- * root ports index starts from 1). Thus keeping lcap_port_base 0x10 for TBT, so that coreboot's
- * PCIe remapping logic can return correct index (0-based)
- */
+ * Document #815002 Panther Lake H Processor - 2.3 Device IDs - Table 8 "Other Device ID"
+ * specifies that the first Thunderbolt PCIe root port number is 21. TBT's LCAP registers return
+ * port index which starts from 21 (usually for other PCIe root ports index starts from
+ * 1). Thus, keeping lcap_port_base 21 for TBT, so that coreboot's PCIe remapping logic can
+ * return a correct index (0-based).
+*/
static const struct pcie_rp_group tbt_rp_groups[] = {
--
To view, visit https://review.coreboot.org/c/coreboot/+/85781?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: merged
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: I44f91f954a4ec06c56dcc90d97e7da2193e9acf2
Gerrit-Change-Number: 85781
Gerrit-PatchSet: 4
Gerrit-Owner: Jérémy Compostella <jeremy.compostella(a)intel.com>
Gerrit-Reviewer: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Reviewer: Pranava Y N <pranavayn(a)google.com>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Attention is currently required from: Jérémy Compostella.
Subrata Banik has posted comments on this change by Jérémy Compostella. ( https://review.coreboot.org/c/coreboot/+/85577?usp=email )
Change subject: cpu/x86/topology: Add module_id to CPU topology
......................................................................
Patch Set 4: Code-Review+2
--
To view, visit https://review.coreboot.org/c/coreboot/+/85577?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: I1c8a76dce48c0539a3f36015674553a2461dec27
Gerrit-Change-Number: 85577
Gerrit-PatchSet: 4
Gerrit-Owner: Jérémy Compostella <jeremy.compostella(a)intel.com>
Gerrit-Reviewer: Frans Hendriks <fhendriks(a)eltan.com>
Gerrit-Reviewer: Pranava Y N <pranavayn(a)google.com>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Jérémy Compostella <jeremy.compostella(a)intel.com>
Gerrit-Comment-Date: Wed, 01 Jan 2025 07:08:36 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Hello build bot (Jenkins),
I'd like you to reexamine a change. Please visit
https://review.coreboot.org/c/coreboot/+/85821?usp=email
to look at the new patch set (#2).
Change subject: mb/asus/p8x7x-series: Drop unused MRC devicetree setting
......................................................................
mb/asus/p8x7x-series: Drop unused MRC devicetree setting
Drop MRC setting usb3.hs_port_switch_mask that since commit ee126348726b
("nb/sandybridge,sb/bd82x6x: Configure USB from southbridge devicetree")
mirrors xhci_switchable_ports and is no longer used separately.
Change-Id: Ic1937461ab45f74f29521a8692629290bfd3c560
Signed-off-by: Keith Hui <buurin(a)gmail.com>
---
M src/mainboard/asus/p8x7x-series/devicetree.cb
1 file changed, 0 insertions(+), 7 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/21/85821/2
--
To view, visit https://review.coreboot.org/c/coreboot/+/85821?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Ic1937461ab45f74f29521a8692629290bfd3c560
Gerrit-Change-Number: 85821
Gerrit-PatchSet: 2
Gerrit-Owner: Keith Hui <buurin(a)gmail.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Attention is currently required from: Angel Pons, Riku Viitanen.
Keith Hui has posted comments on this change by Riku Viitanen. ( https://review.coreboot.org/c/coreboot/+/85772?usp=email )
Change subject: mb/asrock: Add Z77 Extreme4
......................................................................
Patch Set 12:
(2 comments)
Patchset:
PS12:
Do you have to do anything special to make a PS/2 mouse work?
File src/mainboard/asrock/z77_extreme4/early_init.c:
https://review.coreboot.org/c/coreboot/+/85772/comment/24c44145_ad2c92d2?us… :
PS12, Line 10: if (CONFIG(CONSOLE_SERIAL))
The function will no-op itself if this config is not selected, so it's not necessary.
--
To view, visit https://review.coreboot.org/c/coreboot/+/85772?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Idf028c6d411bd501b73a3c526240d0b1d6ecaa0c
Gerrit-Change-Number: 85772
Gerrit-PatchSet: 12
Gerrit-Owner: Riku Viitanen <riku.viitanen(a)protonmail.com>
Gerrit-Reviewer: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Reviewer: Nicholas Chin <nic.c3.14(a)gmail.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-CC: Keith Hui <buurin(a)gmail.com>
Gerrit-Attention: Riku Viitanen <riku.viitanen(a)protonmail.com>
Gerrit-Attention: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Comment-Date: Wed, 01 Jan 2025 06:39:44 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No